# Шаблон проекта на C++ с классами для $project_name

Этот шаблон демонстрирует организацию консольного приложения на C++ с использованием классов, в стиле Microsoft Visual Studio. Он подходит для быстрого старта разработки объектно-ориентированных приложений.

## Структура проекта

- `include/message_printer.h`: Заголовочный файл с объявлением класса `MessagePrinter`.
- `src/message_printer.cpp`: Файл с реализацией методов класса `MessagePrinter`.
- `src/main.cpp`: Главный файл, содержащий функцию `main`, создаёт экземпляр класса и вызывает его методы.
- `Makefile`: Файл для автоматизации сборки проекта.
- `.gitignore`: Исключает скомпили Ascending: скомпилированные и временные файлы.
- `.github/workflows/ci.yml`: Конфигурация непрерывной интеграции через GitHub Actions.

## Установка

1. Убедитесь, что у вас установлен компилятор `g++`. Для установки:
   - На Ubuntu/Debian: `sudo apt install build-essential`
   - На macOS: `xcode-select --install`
   - На Windows: Установите MinGW или используйте WSL.

2. Клонируйте репозиторий или распакуйте этот шаблон.

## Сборка и запуск

1. Соберите проект:
   ```bash
   make
   ```

2. Запустите приложение:
   ```bash
   ./program
   ```

   Вывод: `Сообщение: Тестовый запуск программы`

3. Очистите скомпилированные файлы:
   ```bash
   make clean
   ```

## Структура и назначение файлов

- **`include/message_printer.h`**:
  - Заголовочный файл, содержащий объявление класса `MessagePrinter`.
  - Включает необходимые библиотеки (`<string>`) и использует include-гварды для предотвращения повторного включения.
  - Объявляет конструктор, метод `print` и деструктор.

- **`src/message_printer.cpp`**:
  - Файл с реализацией методов класса `MessagePrinter`.
  - Импортирует `message_printer.h` и `<iostream>` для вывода в консоль.
  - Реализует конструктор, метод `print` и деструктор.

- **`src/main.cpp`**:
  - Главный файл программы, содержащий функцию `main`.
  - Создаёт экземпляр класса `MessagePrinter` и вызывает его метод `print`.

- **`Makefile`**:
  - Автоматизирует сборку проекта.
  - Компилирует исходные файлы (`main.cpp`, `message_printer.cpp`) в объектные файлы и линкует их в исполняемый файл `program`.
  - Использует `g++` с флагами `-Wall` (показывать предупреждения) и `-g` (добавить отладочную информацию).

- **`.gitignore`**:
  - Исключает скомпилированные файлы (`program`, `*.o`) и временные файлы (`.DS_Store`, `*.swp`) из Git.

- **`.github/workflows/ci.yml`**:
  - Настраивает непрерывную интеграцию через GitHub Actions.
  - Выполняет сборку и запуск программы для проверки корректности.

## Настройка и расширение

- **Добавление новых классов**:
  1. Создайте новый заголовочный файл в `include/` с объявлением класса.
  2. Реализуйте методы в новом `.cpp` файле в `src/`.
  3. Обновите `SRCS` в `Makefile`, добавив новый `.cpp` файл.
- **Расширение функциональности**:
  - Добавьте новые методы в класс `MessagePrinter` в `message_printer.h` и реализуйте их в `message_printer.cpp`.
- **Оптимизация**:
  - Измените `CFLAGS` в `Makefile`, например, добавьте `-O2` для оптимизации.

## Зависимости

- Требуется только компилятор `g++` (или совместимый, например, `clang++`).
- Никаких внешних библиотек для базового шаблона не нужно.


---
made by [**Floom**](https://github.com/Floom1)